@@ -25,18 +25,20 @@ signalCalculation <- function(ref_reg, pts, biogeo = TRUE) {
   #IDs of the cells overlapping reference regions
   sps_range_prior_conf <- ref_reg_ID$Presence$prob  
   #a priori confidence of occurrence in each cell
-  pr_index <- numeric()
+  pr_index <- rep(-9999,nrow(pts))
   
   if (biogeo == TRUE) {
-    nat_index <- numeric()
-    alien_index <- numeric()
+    nat_index <- rep(-9999,nrow(pts))
+    alien_index <- rep(-9999,nrow(pts))
   }
   
-  for (i in seq_len(nrow(occ_ID))) {
-
+  #occ_ID$ID_points[i]
+  unique_IDs <- unique(occ_ID$ID_points)
+  for (i in seq_along(unique_IDs)) 
+    {
     dist <- try(suppressWarnings(readRDS(gzcon(url(
       paste0("http://gift.uni-goettingen.de/bracatus/distances/",
-             occ_ID$ID_points[i]))))),
+             unique_IDs[i]))))),
                 silent =TRUE)
     
     if(class(dist) == "try-error"){
@@ -51,17 +53,18 @@ signalCalculation <- function(ref_reg, pts, biogeo = TRUE) {
       #index between 0 and 1, getting only the values for the cells that 
       #send a signal
       
-      if (occ_ID$ID_points[i] %in% sps_range_ID) {
+      if (unique_IDs[i] %in% sps_range_ID) {
         # this part checks whether the point is in a cell that sends a signal, 
         #to include the majoration of the signal sent from the same cell
         pts_value <- sps_range_prior_conf[which(sps_range_ID == 
-                                                  occ_ID$ID_points[i])]
+                                                  unique_IDs[i])]
         #gets the index in the point location
       } else {
         pts_value <- 0
       }
       
-      pr_index[i] <- sum(sps_range_prior_conf * (prox^32), 
+      pr_index[which(occ_ID$ID_points == unique_IDs[i])] <- 
+        sum(sps_range_prior_conf * (prox^32), 
                          na.rm = TRUE) + pts_value * 9
       
       if (biogeo == TRUE) {
@@ -75,17 +78,18 @@ signalCalculation <- function(ref_reg, pts, biogeo = TRUE) {
         #index between 0 and 1, getting only the values for the cells 
         #that send a signal
         
-        if (occ_ID$ID_points[i] %in% sps_nat_range_ID) {
+        if (unique_IDs[i] %in% sps_nat_range_ID) {
           # this part checks whether the point is in a cell that sends a signal,
           #to include the majoration of the signal sent from the same cell
           pts_value <- sps_nat_range_prior_conf[which(sps_nat_range_ID == 
-                                                        occ_ID$ID_points[i])]  
+                                                        unique_IDs[i])]  
           #gets the index in the point location
         } else {
           pts_value <- 0
         }
         
-        nat_index[i] <- sum(sps_nat_range_prior_conf * (nat_prox^32), 
+        nat_index[which(occ_ID$ID_points == unique_IDs[i])] <- 
+          sum(sps_nat_range_prior_conf * (nat_prox^32), 
                             na.rm = TRUE) + pts_value * 9
         
         sps_alien_range_ID <- ref_reg_ID$Alien$cell_ID  
@@ -98,17 +102,18 @@ signalCalculation <- function(ref_reg, pts, biogeo = TRUE) {
         #index between 0 and 1, getting only the values for the cells that 
         #send a signal
         
-        if (occ_ID$ID_points[i] %in% sps_alien_range_ID) {
+        if (unique_IDs[i] %in% sps_alien_range_ID) {
           # this part checks whether the point is in a cell that sends a signal,
           #to include the majoration of the signal sent from the same cell
           pts_value <- sps_alien_range_prior_conf[which(sps_alien_range_ID ==
-                                                      occ_ID$ID_points[i])]
+                                                          unique_IDs[i])]
           #gets the index in the point location
         } else {
           pts_value <- 0
         }
         
-        alien_index[i] <- sum(sps_alien_range_prior_conf * (alien_prox^32), 
+        alien_index[which(occ_ID$ID_points == unique_IDs[i])] <- 
+          sum(sps_alien_range_prior_conf * (alien_prox^32), 
                               na.rm = TRUE) + pts_value * 9
       }
     }
